@@ -13,6 +13,11 @@
   q2 <- ifelse(!is.null(WHERE), paste0(q, " AND (", WHERE, ")"), q)
   sacatalog <- suppressMessages(SDA_query(q2))
 
+  if (is.null(sacatalog)) {
+    return(try(stop("Query of Soil Survey Area Catalog (", 
+                    WHERE, ") failed to return any data", call. = FALSE), silent = TRUE))
+  }
+  
   areasymbol <- sacatalog$areasymbol
   saverest <- sacatalog$saverest
   statecode <- substr(areasymbol, 0, 2)
